# Best Practices for Community Spend Proposals

## Preparing your proposal

In order to define your project and start to gather support, you'll want to
start with the minimal, critical components:

- Name of your project
- Value to the Cosmos Hub
- Rough timeline
- Estimated amount of funding

You should be able to use these to enagage with a key stakeholder (eg. a large validator operator) with a few short sentences to measure their support. Here's an example:

"We are considering a proposal for funding to work on `project`. We think it will help the Hub to `outcome`. Timeline is `x`, and we're asking for `y` amount. Do you think that this is a proposal that `large validator` may support?"

**Why a large validator?** They tend to be the de facto decision-makers on the Cosmos Hub, since their delegators also delegate their voting power. If you can establish a base layer of off-chain support, you can be more confident that it's worth proceeding to the next stage.

**Note:** many will likely hesitate to commit support, and that's okay. It will be important to reassure these stakeholders that this isn't a binding a commitment. You're just canvasing the community to get a feel for whether it's worthwhile to proceed. It's also an opportunity to connect with new people and to answer their questions about what it is you're working on. It will be important for them to clearly understand why you think what you're proposing will be valuable to the Cosmos Hub, and if possible, why it will be valuable to them as long-term stakeholders.

## Elements of a Community-Spend Proposal

It will be important to balance two things: being detailed and being concise. You'll want to be concise so that people can assess your proposal quickly. You'll want to be detailed so that people will have a clear understanding of what the agreement is and won't need to ask many questions before voting. These are some elements that the Cosmos Hub community may be likely to be looking for:

1. Summary - the key details of the proposal
   - who is submitting the proposal
   - the amount of the proposal
   - the items being delivered deliverable
   - the date for which the deliverables will be met
   - a short summary of the history (what compelled this proposal), solution that's being presented, and future expectations

Assume that nobody will read beyond this point.

2. Applicant(s) - the profile of the person(s)/entity making the proposal
   - who you are and your involvement in Cosmos and/or other blockchain networks
   - an overview of team members involved and their relevant experience
   - brief mission statment for your organization/business (if applicable) eg. website
   - past work you've done eg. include your Github
   - some sort of proof of who you are eg. Keybase
3. Problem - generally what you're solving and/or opportunity you're addressing
   - past, present (and possibly a prediction of the future without this work being done)
4. Solution - generally how you're proposing to deliver the solution
   - your plan to fix the problem or deliver value
   - the beneficiaries of this plan (ie. who will your plan impact and how?)
     - follow the "as a user" template ie. write a short user story about the problem you are trying to solve and how users will interact with what you're proposing to deliver (eg. benefits and functionality from a user’s perspective)
     - voters should understand the value of what you're providing in a simple way
   - your reasons for selecting this plan
   - your motivation for delivering this solution/value
5. Funding - amount and denomination proposed eg. 5000 ATOM
   - the entity controlling the account receiving the funding
   - consider an itemized breakdown of funding per major deliverable
   - consider outlining how the funds will be spent
6. Deliverables and timeline - the specifics of what you're delivering and how, and what to expect
   - what are the specific deliverables? (be detailed)
   - when will each of these be delivered?
   - will there be a date at which the project will be considered failed if the deliverables have not been met?
   - how will each of these be delivered?
   - what will happen if you do not deliver on time?
     - what is the deadline for the project to be considered failed?
     - do you have a plan to return the funds?
   - how will you be accountable to the Cosmos Hub stakeholders?
     - how will you communicate updates and how often?
     - how can the community observe your progress?
     - how can the community provide feedback?
   - how should the quality of deliverables be assessed? eg. metrics
7. Relationships and disclosures
   - have you received or applied for grants or funding? for similar work? eg. from the Interchain Foundation
   - how will you and/or your organization benefit?
   - do you see this work continuing in the future and is there a plan?
   - what are the risks involved with this work?
   - do you have conflicts of interest to declare?
