**Introduction**

IBC and Hub go-to-market is a complex organizational, developmental, and marketing undertaking that involves many entities, software projects, and services. IBC is also intimately bound up to the roadmap, development, and go-to-market of Gaia. Though it is possible to bring IBC to market without Gaia, Gaia should be the primary vehicle and product we are concerned with, since the value of Gaia stems from the utility it brings to the ecosystem of chains connected to and benefiting from its position as a Hub. Thus, this plan will consider go-to-market needs for IBC and Gaia simultaneously. The roadmap will be designed to ensure that IBC is valuable to the Hub and its users, including the many interconnected sovereign blockchains that derive utility from the Hub.

The IBC and Gaia go-to-market initiatives will be about direct engagement with the products that directly validate the utility of the Hub and IBC. This initiative encompasses the utility of various interoperable and cross-chain Cosmos entities such as application-specific blockchains, Bridges, Relayers, Validators, etc. More importantly, we envision that the market will quickly grasp the meaning and relevance of cross-chain interoperability of which Cosmos is a leading contender.
This is an evolving document and process. Please feel free to contribute where you think something is missing or could be improved!
**How we work**

These discussions will take place during weekly Gaia team calls. The Hub will determine the value proposition of IBC and how it is integrated into Gaia and how it will serve the larger ecosystem of interconnected blockchains. These discussions will continue to take place with key stakeholders during the bi-weekly Cosmos multi entity call. Importantly, the purpose of the bi-weekly multi entity call will be to consider all technical aspects of IBC launch from a strategic perspective (outlined in &#39;What&#39;s Needed to Successfully Go to Market?&#39;). This will inform the agenda.

Leading up to Stargate, IBC Development was led by Chris Goes (Interchain Berlin), while Gaia did not have a maintainer. Go-to-market for Stargate was led by Zaki (Iqlusion). Moving forward, we are aiming to organize Cosmos Hub leadership under Shahan Khatchadourian (Interchain Berlin) and go-to-market led by Jelena Djuric (Informal Systems). Both Shahan and Jelena are being onboarded into these roles with the support of previous leads. 

Execution and completion will be tracked via a meta-project dashboard ([Gaia Roadmap](https://github.com/cosmos/gaia/projects/6)) that incorporates the high level objectives for each phase roll out. Each phase (i.e. Phase 1 - Accounts UX, Phase 2 - Interchain Interchange, etc) will have their own project dashboard that will link to the repos, issues, PRs, etc, where development is taking place.

&quot;_Never doubt that a small group of thoughtful, committed, citizens can change the world. Indeed, it is the only thing that ever has.&quot; - Margaret Mead_

**What&#39;s Needed to Successfully Go to Market?**

1. **Project management**

In sum, project management will focus on surfacing issues, dependencies, relative roadmaps, and coordinating across all stakeholders. Questions that will be considered throughout each phase of the Gaia roadmap:

- What is missing from an integration points perspective with end users?

- Which relationships are missing?
- What&#39;s the highest priority? Least priority?

2. **Market validation**

The user is paramount. For Gaia and IBC, we see the users being:

  - ATOM holders
  - Existing zones
  - New zones
  - Validators on hub and zones
  - Nodes on hub and zones
  - Other service providers on hubs and zones (wallets, explorers, exchanges, etc.)

We will also want to be tracking outreach to the relevant users per phase to ensure that Hub utility (and IBC where appropriate) are being validated. Spotlights on experiments will continue to validate the utility of the Hub and IBC (i.e. bridge to Ethereum, AMM, etc). We will also be conducting continous outbound outreach to look for partners that are aligned with the interchain mission.

3. **Communications**

Communications should focus on the features of IBC and the Hub that demonstrate the most utility for users. Stories should answer questions such as:

- How does IBC relate to ATOM and the Hub?
- How does IBC derive its value from the Hub, and vice versa?
- Why should you build your blockchain with IBC?
- How does a blockchain benefit from connecting to the Hub?

4. **Technical Support**

We will need technical support for users depending on the phase that is being rolled out. A phase rollout is not complete without proper technical support.

Further, we will need technical support that goes beyond the different phase rollouts. Importantly, to create an IBC connected blockchain developers will need the following things:

- A value proposition

  - A State Machine:
    - Built on Cosmos SDK
    - ABCI
    - Cosmos-rs.. etc
  - Security:
    - Cross chain Validation
    - Validator set formation
  - Community
    - Discoverability Opportunities
  - Connectivity
  - Visibility
    - Wallet, Block Explorer, etc

5. **METRICS: How do we know when IBC is succeeding? How do we know when Hub is providing value to an interconnected ecosystem of sovereign blockchains?**

The go-to-market team should be tracking the extent to which IBC is succeeding or failing in terms of key metrics. This will require continuous experimentation and coordination between entities. An example of a metric that best represents IBC go to market would be # of distinct IBC connections that transport x amount of value. To get to these metrics we need the developer resources and proven business models that encourage developers to use this technology.

The Cosmos-SDK exposes some [existing metrics for IBC](https://docs.cosmos.network/master/core/telemetry.html#supported-metrics).
